@@ -11,7 +11,7 @@
     This file is part of mss.
 
     :copyright: Copyright 2016 Reimar Bauer
-    :copyright: Copyright 2016-2018 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2019 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -102,7 +102,7 @@ def main():
 
         def authfunc(environ, username, password):
             for u, p in mss_wms_auth.allowed_users:
-                if (u == username) and (p == hashlib.md5(password).hexdigest()):
+                if (u == username) and (p == hashlib.md5(password.encode('utf-8')).hexdigest()):
                     return True
             return False
 
